@@ -1,4 +1,4 @@
-# $Id: ODBC.pm 15556 2013-01-17 15:56:40Z mjevans $
+# $Id: ODBC.pm 15562 2013-01-21 12:07:49Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
 # portions Copyright (c) 1997-2004  Jeff Urlwin
@@ -19,7 +19,7 @@ require 5.008;
 # see discussion on dbi-users at
 # http://www.nntp.perl.org/group/perl.dbi.dev/2010/07/msg6096.html and
 # http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-$DBD::ODBC::VERSION = '1.42_3';
+$DBD::ODBC::VERSION = '1.42_4';
 
 {
     ## no critic (ProhibitMagicNumbers ProhibitExplicitISA)
@@ -32,7 +32,7 @@ $DBD::ODBC::VERSION = '1.42_3';
 
     @ISA = qw(Exporter DynaLoader);
 
-    # my $Revision = substr(q$Id: ODBC.pm 15556 2013-01-17 15:56:40Z mjevans $, 13,2);
+    # my $Revision = substr(q$Id: ODBC.pm 15562 2013-01-21 12:07:49Z mjevans $, 13,2);
 
     require_version DBI 1.609;
 
@@ -197,7 +197,9 @@ $DBD::ODBC::VERSION = '1.42_3';
             odbc_driver_complete           => undef,
             odbc_batch_size                => undef,
             odbc_array_operations          => undef, # sth and dbh
-            odbc_taf_callback              => undef
+            odbc_taf_callback              => undef,
+            odbc_trace                          => undef, # dbh
+            odbc_trace_file                          => undef, # dbh
         };
     }
 
@@ -651,7 +653,7 @@ DBD::ODBC - ODBC Driver for DBI
 
 =head1 VERSION
 
-This documentation refers to DBD::ODBC version 1.42_3.
+This documentation refers to DBD::ODBC version 1.42_4.
 
 =head1 SYNOPSIS
 
@@ -707,37 +709,6 @@ you won't being doing updates.
 
 This attribute requires DBI version 1.55 or better.
 
-=head2 Private attributes which may be used in the connect method
-
-=head3 odbc_trace_file
-
-Specify the name and path to a file you want ODBC API trace
-information to be written to. See L</odbc_trace>.
-
-=head3 odbc_trace
-
-Enable or disable ODBC API tracing. Set to 1 to enable and 0 to
-disable.
-
-This calls SQLSetConnectAttr for SQL_ATTR_TRACE and either sets
-SQL_OPT_TRACE_ON or SQL_OPT_TRACE_OFF. Enabling tracing will tell
-the ODBC driver manager to write and ODBC API trace to the file
-named with L</odbc_trace_file>.
-
-NOTE: If you don't set odbc_trace_file most ODBC Driver Managers write
-to a file called SQL.LOG in the root directory (but this depends on
-the driver manager used).
-
-NOTE: This tracing is produced by the ODBC Driver Manager and has
-nothing to do with DBD::ODBC other than it should trace the ODBC
-calls DBD::ODBC makes i.e., DBD::ODBC is not responsible for the
-tracing mechanism itself.
-
-NOTE: Enabling tracing will probably slow your application down a lot.
-I'd definitely think twice about it if in a production environment
-unless you are desperate as it tends to produce very large trace
-files for short periods of ODBC activity.
-
 =head2 Private attributes common to connection and statement handles
 
 =head3 odbc_ignore_named_placeholders
@@ -1405,6 +1376,35 @@ see others I cannot create a generic interface. I'll happily accept
 patches for any other driver or if you send me a working copy of the
 driver and the documentation I will add support for it.
 
+=head3 odbc_trace_file
+
+Specify the name and path to a file you want ODBC API trace
+information to be written to. See L</odbc_trace>.
+
+=head3 odbc_trace
+
+Enable or disable ODBC API tracing. Set to 1 to enable and 0 to
+disable.
+
+This calls SQLSetConnectAttr for SQL_ATTR_TRACE and either sets
+SQL_OPT_TRACE_ON or SQL_OPT_TRACE_OFF. Enabling tracing will tell
+the ODBC driver manager to write and ODBC API trace to the file
+named with L</odbc_trace_file>.
+
+NOTE: If you don't set odbc_trace_file most ODBC Driver Managers write
+to a file called SQL.LOG in the root directory (but this depends on
+the driver manager used).
+
+NOTE: This tracing is produced by the ODBC Driver Manager and has
+nothing to do with DBD::ODBC other than it should trace the ODBC
+calls DBD::ODBC makes i.e., DBD::ODBC is not responsible for the
+tracing mechanism itself.
+
+NOTE: Enabling tracing will probably slow your application down a lot.
+I'd definitely think twice about it if in a production environment
+unless you are desperate as it tends to produce very large trace
+files for short periods of ODBC activity.
+
 =head2 Private statement attributes
 
 =head3 odbc_more_results
